@@ -1,7 +1,6 @@
 #check if matrix is unitary
 #' @export
-unitary <- function(m){
-	epsilon <- 1e-15
+unitary <- function(m,epsilon=1e-13){
 	i <- complex(1,0,1)
 	#Inverse is equal to adjoint
 	#all(solve(m) == adjoint(m)) #issues with precision prevent from working
